@@ -52,8 +52,8 @@ class MsSqlProvider(DatabaseProvider):
         db_user,
         db_pass,
         db_name,
+        seed_rows,
         db_port=None,
-        seed_rows=None,
         backup_compression=False,
         driver=None,
     ):
@@ -70,9 +70,6 @@ class MsSqlProvider(DatabaseProvider):
         self.db_name = db_name
         self.db_port = db_port
 
-        if seed_rows is None:
-            seed_rows = 150
-
         self.seed_rows = int(seed_rows)
 
         self.__conn = None
